@@ -10,7 +10,7 @@ class CommonTestCase(unittest.TestCase):
 
     #region Constructor
 
-    def __init__(self, tableDataFrame: DataFrame, fieldInfo: {(str, type)}, customEvents: [TestEvent], methodName: str = "runTest"):
+    def __init__(self, tableDataFrame: DataFrame, fieldInfo: [(str, type)], customEvents: [TestEvent], methodName: str = "runTest"):
         super(CommonTestCase, self).__init__(methodName)
         self.__tableDataFrame = tableDataFrame
         self.__fieldInfo = fieldInfo
